@@ -25,30 +25,30 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-open-location-dialog.c,v 1.2 2005/12/12 17:27:56 pborelli Exp $
+ * $Id: gedit-open-location-dialog.c,v 1.3 2006/11/19 17:02:16 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
-#include "gedit-open-location-dialog.h"
-
 #include <glib/gi18n.h>
-
-#include <libgnomeui/gnome-entry.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
+#include "gedit-open-location-dialog.h"
+#include "gedit-history-entry.h"
 #include "gedit-encodings-option-menu.h"
 #include "gedit-utils.h"
 #include "gedit-help.h"
 
-#define GEDIT_OPEN_LOCATION_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_OPEN_LOCATION_DIALOG, GeditOpenLocationDialogPrivate))
+#define GEDIT_OPEN_LOCATION_DIALOG_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+							GEDIT_TYPE_OPEN_LOCATION_DIALOG, \
+							GeditOpenLocationDialogPrivate))
 
 struct _GeditOpenLocationDialogPrivate 
 {
-	GtkWidget *uri;
-	GtkWidget *uri_list;
+	GtkWidget *uri_entry;
+	GtkWidget *uri_text_entry;
 	GtkWidget *encoding_menu;
 };
 
@@ -63,14 +63,14 @@ gedit_open_location_dialog_class_init (GeditOpenLocationDialogClass *klass)
 }
 
 static void 
-entry_changed (GtkEditable             *editable, 
+entry_changed (GtkComboBox             *combo, 
 	       GeditOpenLocationDialog *dlg)
 {
 	const gchar *str;
-	
-	str = gtk_entry_get_text (GTK_ENTRY (dlg->priv->uri));		
+
+	str = gtk_entry_get_text (GTK_ENTRY (dlg->priv->uri_text_entry));
 	g_return_if_fail (str != NULL);
-	
+
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dlg), 
 					   GTK_RESPONSE_OK,
 					   (str[0] != '\0'));
@@ -91,24 +91,23 @@ response_handler (GeditOpenLocationDialog *dlg,
 					    NULL);
 
 			g_signal_stop_emission_by_name (dlg, "response");
-			
 			break;
-			
+
 		case GTK_RESPONSE_OK:
 			uri = gedit_open_location_dialog_get_uri (dlg);
 			if (uri != NULL)
-			{	
-				g_free (uri);
-				uri = gtk_editable_get_chars (GTK_EDITABLE (dlg->priv->uri),
-							      0,
-							      -1);
-				gnome_entry_prepend_history (GNOME_ENTRY (dlg->priv->uri_list), 
-						     	     TRUE,
-						     	     uri);
+			{
+				const gchar *text;
+
+				text = gtk_entry_get_text
+						(GTK_ENTRY (dlg->priv->uri_text_entry));
+				gedit_history_entry_prepend_text
+						 (GEDIT_HISTORY_ENTRY (dlg->priv->uri_entry),
+						  text);
+
 				g_free (uri);
 			}
-			
-			break;					     	     
+			break;
 	}
 }
 
@@ -116,13 +115,15 @@ static void
 gedit_open_location_dialog_init (GeditOpenLocationDialog *dlg)
 {	
 	GtkWidget *content;
+	GtkWidget *vbox;
+	GtkWidget *location_label;
 	GtkWidget *encoding_label;
 	GtkWidget *encoding_hbox;
 	GtkWidget *error_widget;
 	gboolean   ret;
-	
+
 	dlg->priv = GEDIT_OPEN_LOCATION_DIALOG_GET_PRIVATE (dlg);
-	
+
 	gtk_dialog_add_buttons (GTK_DIALOG (dlg),
 				GTK_STOCK_CANCEL, 
 				GTK_RESPONSE_CANCEL,
@@ -151,8 +152,8 @@ gedit_open_location_dialog_init (GeditOpenLocationDialog *dlg)
 					     "open_uri_dialog_content",
 					     &error_widget,
 					     "open_uri_dialog_content", &content,
-					     "uri", &dlg->priv->uri,
-					     "uri_list", &dlg->priv->uri_list,
+					     "main_vbox", &vbox,
+					     "location_label", &location_label,
 					     "encoding_label", &encoding_label,
 					     "encoding_hbox", &encoding_hbox,
 					     NULL);
@@ -166,7 +167,20 @@ gedit_open_location_dialog_init (GeditOpenLocationDialog *dlg)
 
 		return;
 	}
-		
+
+	dlg->priv->uri_entry = gedit_history_entry_new ("gedit2_uri_list");
+	dlg->priv->uri_text_entry = gedit_history_entry_get_entry (GEDIT_HISTORY_ENTRY (dlg->priv->uri_entry));
+	gtk_entry_set_activates_default (GTK_ENTRY (dlg->priv->uri_text_entry), TRUE);
+	gtk_widget_show (dlg->priv->uri_entry);
+	gtk_box_pack_start (GTK_BOX (vbox),
+			    dlg->priv->uri_entry,
+			    FALSE,
+			    FALSE,
+			    0);
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (location_label),
+				       dlg->priv->uri_entry);
+
 	dlg->priv->encoding_menu = gedit_encodings_option_menu_new (FALSE);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (encoding_label),
@@ -180,14 +194,13 @@ gedit_open_location_dialog_init (GeditOpenLocationDialog *dlg)
 
 	gtk_widget_show (dlg->priv->encoding_menu);
 
-	g_signal_connect (G_OBJECT (dlg->priv->uri), 
+	g_signal_connect (dlg->priv->uri_entry,
 			  "changed",
 			  G_CALLBACK (entry_changed), 
 			  dlg);
-			  
+
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
 			    content, FALSE, FALSE, 0);
-
 }
 
 GtkWidget *
@@ -200,7 +213,7 @@ gedit_open_location_dialog_new (GtkWindow *parent)
 	if (parent != NULL)
 		gtk_window_set_transient_for (GTK_WINDOW (dlg),
 					      parent);
-					      
+
 	return dlg;
 }
 
@@ -212,24 +225,24 @@ gedit_open_location_dialog_get_uri (GeditOpenLocationDialog *dlg)
 	gchar *uri;
 	gchar *canonical_uri;
 	GnomeVFSURI *vfs_uri;
-	
+
 	g_return_val_if_fail (GEDIT_IS_OPEN_LOCATION_DIALOG (dlg), NULL);
-	
-	str = gtk_entry_get_text (GTK_ENTRY (dlg->priv->uri));		
+
+	str = gtk_entry_get_text (GTK_ENTRY (dlg->priv->uri_text_entry));
 	g_return_val_if_fail (str != NULL, NULL);
-	
+
 	if (str[0] == '\0')
 		return NULL;
-		
+
 	uri = gnome_vfs_make_uri_from_input_with_dirs (str,
 						       GNOME_VFS_MAKE_URI_DIR_CURRENT);
 	g_return_val_if_fail (uri != NULL, NULL);
-	
+
 	canonical_uri = gnome_vfs_make_uri_canonical (uri);
 	g_free (uri);
-	
+
 	g_return_val_if_fail (canonical_uri != NULL, NULL);
-	
+
 	vfs_uri = gnome_vfs_uri_new (canonical_uri);
 	if (vfs_uri == NULL)
 	{
@@ -238,6 +251,7 @@ gedit_open_location_dialog_get_uri (GeditOpenLocationDialog *dlg)
 	}
 
 	gnome_vfs_uri_unref (vfs_uri);
+
 	return canonical_uri;
 }
 
