@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-app.h,v 1.4 2006/06/11 14:17:15 sfre Exp $
+ * $Id: gedit-app.h,v 1.5 2006/08/16 17:45:04 pborelli Exp $
  */
 
 #ifndef __GEDIT_APP_H__
@@ -121,6 +121,12 @@ void		 _gedit_app_set_lockdown		(GeditApp          *app,
 void		 _gedit_app_set_lockdown_bit		(GeditApp          *app,
 							 GeditLockdownMask  bit,
 							 gboolean           value);
+/*
+ * This one is a gedit-window function, but we declare it here to avoid
+ * #include headaches since it needs the GeditLockdownMask declaration.
+ */
+void		 _gedit_window_set_lockdown		(GeditWindow         *window,
+							 GeditLockdownMask    lockdown);
 
 
 G_END_DECLS
