@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.c,v 1.39 2006/09/23 14:37:09 pborelli Exp $
+ * $Id: gedit-window.c,v 1.45 2006/12/02 16:24:02 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -168,13 +168,10 @@ gedit_window_finalize (GObject *object)
 }
 
 static void
-gedit_window_destroy (GtkObject *object)
+save_panes_state (GeditWindow *window)
 {
-	GeditWindow *window;
 	gint pane_page;
 
-	window = GEDIT_WINDOW (object);
-
 	if (gedit_prefs_manager_window_size_can_set ())
 		gedit_prefs_manager_set_window_size (window->priv->width,
 						     window->priv->height);
@@ -201,6 +198,20 @@ gedit_window_destroy (GtkObject *object)
 	if (pane_page != 0 &&
 	    gedit_prefs_manager_bottom_panel_active_page_can_set ())
 		gedit_prefs_manager_set_bottom_panel_active_page (pane_page);
+}
+
+static void
+gedit_window_destroy (GtkObject *object)
+{
+	GeditWindow *window;
+
+	window = GEDIT_WINDOW (object);
+
+	if (!window->priv->destroy_has_run)
+	{
+		save_panes_state (window);
+		window->priv->destroy_has_run = TRUE;
+	}
 
 	GTK_OBJECT_CLASS (gedit_window_parent_class)->destroy (object);
 }
@@ -244,29 +255,34 @@ gedit_window_configure_event (GtkWidget         *widget,
  * GtkWindow catches keybindings for the menu items _before_ passing them to
  * the focused widget. This is unfortunate and means that pressing ctrl+V
  * in an entry on a panel ends up pasting text in the TextView.
- * Here we force events to be first  passed to the focused widget and then
- * we chain up the default handler... this is the opposite of Gtk default
- * behavior so we need to keep an eye open to see if anything breaks.
+ * Here we override GtkWindow's handler to do the same things that it
+ * does, but in the opposite order and then we chain up to the grand
+ * parent handler, skipping gtk_window_key_press_event.
  */
 static gboolean
 gedit_window_key_press_event (GtkWidget   *widget,
 			      GdkEventKey *event)
 {
-	GtkWidget *focused_widget;
+	static gpointer grand_parent_class = NULL;
+	GtkWindow *window = GTK_WINDOW (widget);
 	gboolean handled = FALSE;
 
-	focused_widget = gtk_window_get_focus (GTK_WINDOW (widget));
+	if (grand_parent_class == NULL)
+		grand_parent_class = g_type_class_peek_parent (gedit_window_parent_class);
 
-	if (focused_widget)
-	{
-		handled = gtk_widget_event (focused_widget,
-					    (GdkEvent*) event);
-	}
+	/* handle focus widget key events */
+	if (!handled)
+		handled = gtk_window_propagate_key_event (window, event);
 
-	if (handled)
-		return TRUE;
-	else
-		return GTK_WIDGET_CLASS (gedit_window_parent_class)->key_press_event (widget, event);
+	/* handle mnemonics and accelerators */
+	if (!handled)
+		handled = gtk_window_activate_key (window, event);
+
+	/* Chain up, invokes binding set */
+	if (!handled)
+		handled = GTK_WIDGET_CLASS (grand_parent_class)->key_press_event (widget, event);
+
+	return handled;
 }
 
 static void
@@ -670,7 +686,7 @@ set_sensitivity_according_to_tab (GeditWindow *window,
 				  state_normal);
 
 	action = gtk_action_group_get_action (window->priv->action_group,
-					      "SearchInteractiveSearch");
+					      "SearchIncrementalSearch");
 	gtk_action_set_sensitive (action,
 				  state_normal);
 
@@ -1049,7 +1065,7 @@ recent_manager_changed (GtkRecentManager *manager,
 	update_recent_files_menu (window);
 }
 
-#define TIP_MAX_URI_LEN 100
+
 
 /*
  * Manually construct the inline recents list in the File menu.
@@ -1061,6 +1077,7 @@ update_recent_files_menu (GeditWindow *window)
 	GeditWindowPrivate *p = window->priv;
 	gint max_recents;
 	GList *actions, *l, *items;
+	GList *filtered_items = NULL;
 	gint i;
 
 	gedit_debug (DEBUG_WINDOW);
@@ -1088,17 +1105,30 @@ update_recent_files_menu (GeditWindow *window)
 
 	items = gtk_recent_manager_get_items (p->recent_manager);
 
-	items = g_list_sort (items, (GCompareFunc) sort_recents_mru);
+	/* filter */
+	for (l = items; l != NULL; l = l->next)
+	{
+		GtkRecentInfo *info = l->data;
+
+		if (!gtk_recent_info_has_group (info, "gedit"))
+			continue;
+
+		filtered_items = g_list_prepend (filtered_items, info);
+	}
+
+	/* sort */
+	filtered_items = g_list_sort (filtered_items,
+				      (GCompareFunc) sort_recents_mru);
 
 	i = 0;
-	for (l = items; l != NULL; l = l->next)
+	for (l = filtered_items; l != NULL; l = l->next)
 	{
 		gchar *action_name;
 		const gchar *display_name;
 		gchar *escaped;
 		gchar *label;
 		gchar *uri;
-		gchar *trunc_uri;
+		gchar *ruri;
 		gchar *tip;
 		GtkAction *action;
 		GtkRecentInfo *info = l->data;
@@ -1107,10 +1137,6 @@ update_recent_files_menu (GeditWindow *window)
 		if (i >= max_recents)
 			break;
 
-		/* filter */
-		if (!gtk_recent_info_has_group (info, "gedit"))
-			continue;
-
 		i++;
 
 		action_name = g_strdup_printf ("recent-info-%d", i);
@@ -1130,13 +1156,12 @@ update_recent_files_menu (GeditWindow *window)
 		/* gtk_recent_info_get_uri_display (info) is buggy and
 		 * works only for local files */
 		uri = gedit_utils_format_uri_for_display (gtk_recent_info_get_uri (info));
-		trunc_uri = gedit_utils_str_middle_truncate (uri,
-							     TIP_MAX_URI_LEN);
+		ruri = gedit_utils_replace_home_dir_with_tilde (uri);
 		g_free (uri);
 
 		/* Translators: %s is a URI */
-		tip = g_strdup_printf (_("Open '%s'"), trunc_uri);
-		g_free (trunc_uri);
+		tip = g_strdup_printf (_("Open '%s'"), ruri);
+		g_free (ruri);
 
 		action = gtk_action_new (action_name,
 					 label,
@@ -1169,12 +1194,12 @@ update_recent_files_menu (GeditWindow *window)
 		g_free (tip);
 	}
 
+	g_list_free (filtered_items);
+
 	g_list_foreach (items, (GFunc) gtk_recent_info_unref, NULL);
 	g_list_free (items);
 }
 
-#undef TIP_MAX_URI_LEN
-
 static void
 set_non_homogeneus (GtkWidget *widget, gpointer data)
 {
@@ -1427,6 +1452,27 @@ documents_list_menu_activate (GtkToggleAction *action,
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (window->priv->notebook), n);
 }
 
+static gchar *
+get_menu_tip_for_tab (GeditTab *tab)
+{
+	GeditDocument *doc;
+	gchar *uri;
+	gchar *ruri;
+	gchar *tip;
+
+	doc = gedit_tab_get_document (tab);
+
+	uri = gedit_document_get_uri_for_display (doc);
+	ruri = gedit_utils_replace_home_dir_with_tilde (uri);
+	g_free (uri);
+
+	/* Translators: %s is a URI */
+	tip =  g_strdup_printf (_("Activate '%s'"), ruri);
+	g_free (ruri);
+	
+	return tip;
+}
+
 static void
 update_documents_list_menu (GeditWindow *window)
 {
@@ -1481,7 +1527,7 @@ update_documents_list_menu (GeditWindow *window)
 		action_name = g_strdup_printf ("Tab_%d", i);
 		tab_name = _gedit_tab_get_name (GEDIT_TAB (tab));
 		name = gedit_utils_escape_underscores (tab_name, -1);
-		tip =  g_strdup_printf (_("Activate %s"), tab_name);
+		tip =  get_menu_tip_for_tab (GEDIT_TAB (tab));
 
 		/* alt + 1, 2, 3... 0 to switch to the first ten tabs */
 		accel = (i < 10) ? g_strdup_printf ("<alt>%d", (i + 1) % 10) : NULL;
@@ -2078,11 +2124,12 @@ update_window_state (GeditWindow *window)
 						  window->priv->state,
 						  window->priv->num_tabs_with_error);	
 	}
-	
 }
 
 static void
-sync_state (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
+sync_state (GeditTab    *tab,
+	    GParamSpec  *pspec,
+	    GeditWindow *window)
 {
 	gedit_debug (DEBUG_WINDOW);
 	
@@ -2097,7 +2144,9 @@ sync_state (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
 }
 
 static void
-sync_name (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
+sync_name (GeditTab    *tab,
+	   GParamSpec  *pspec,
+	   GeditWindow *window)
 {
 	GtkAction *action;
 	gchar *action_name;
@@ -2107,10 +2156,16 @@ sync_name (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
 	gint n;
 	GeditDocument *doc;
 
-	if (tab != window->priv->active_tab)
-		return;
+	if (tab == window->priv->active_tab)
+	{
+		set_title (window);
 
-	set_title (window);
+		doc = gedit_tab_get_document (tab);
+		action = gtk_action_group_get_action (window->priv->action_group,
+						      "FileRevert");
+		gtk_action_set_sensitive (action,
+					  !gedit_document_is_untitled (doc));
+	}
 
 	/* sync the item in the documents list menu */
 	n = gtk_notebook_page_num (GTK_NOTEBOOK (window->priv->notebook),
@@ -2122,7 +2177,7 @@ sync_name (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
 
 	tab_name = _gedit_tab_get_name (tab);
 	escaped_name = gedit_utils_escape_underscores (tab_name, -1);
-	tip =  g_strdup_printf (_("Activate %s"), tab_name);
+	tip =  get_menu_tip_for_tab (tab);
 
 	g_object_set (action, "label", escaped_name, NULL);
 	g_object_set (action, "tooltip", tip, NULL);
@@ -2132,12 +2187,6 @@ sync_name (GeditTab *tab, GParamSpec *pspec, GeditWindow *window)
 	g_free (escaped_name);
 	g_free (tip);
 
-	doc = gedit_tab_get_document (tab);
-	action = gtk_action_group_get_action (window->priv->action_group,
-					      "FileRevert");
-	gtk_action_set_sensitive (action,
-				  !gedit_document_is_untitled (doc));
-
 	gedit_plugins_engine_update_plugins_ui (window, FALSE);
 }
 
@@ -3057,6 +3106,7 @@ gedit_window_init (GeditWindow *window)
 	window->priv->num_tabs = 0;
 	window->priv->removing_tabs = FALSE;
 	window->priv->state = GEDIT_WINDOW_STATE_NORMAL;
+	window->priv->destroy_has_run = FALSE;
 
 	window->priv->window_group = gtk_window_group_new ();
 	gtk_window_group_add_window (window->priv->window_group, GTK_WINDOW (window));
